<?php

/**
 * @file
 * Administrative pages of klaro module.
 */

/**
 * Builds configuration form.
 *
 * @ingroup forms
 */
function klaro_config_form(array $form, array &$form_state) {

  $form['klaro_enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable Klaro Consent Manager'),
    '#description' => t('Enable Klaro Consent Manager and adapt JS for Matomo and Google Analytics.'),
    '#default_value' => variable_get('klaro_enabled', FALSE),
  );

  // Klaro-Settings.
  $form['klaro'] = array(
    '#type' => 'fieldset',
    '#title' => t('Klaro-Settings'),
  );
  $form['klaro']['klaro_cookie_expires'] = array(
    '#type' => 'textfield',
    '#maxlength' => 3,
    '#title' => t('Duration (in days) for cookie expire'),
    '#default_value' => variable_get('klaro_cookie_expires', 365),
  );
  $form['klaro']['klaro_policy_url'] = array(
    '#type' => 'textfield',
    '#maxlength' => 250,
    '#title' => t('URL for Privacy Policy'),
    '#attributes' => [
      'placeholder' => 'node/123',
    ],
    '#default_value' => variable_get('klaro_policy_url'),
  );
  $form['klaro']['klaro_consent_notice_description'] = array(
    '#type' => 'textfield',
    '#maxlength' => 250,
    '#title' => t('Text for consent notice'),
    '#description' => t('Make use of the placeholder {purposes} to add a list of purposes, which are used by scripts.'),
    '#default_value' => variable_get('klaro_consent_notice_description', t('We collect and process your personal information for the following purposes: {purposes}. By using this site you are giving your consent for us to set cookies.')),
  );
  $form['klaro']['klaro_consent_button'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display button to open consent'),
    '#default_value' => variable_get('klaro_consent_button', TRUE),
  );
  $form['klaro']['klaro_consent_button_text'] = array(
    '#type' => 'textfield',
    '#maxlength' => 250,
    '#title' => t('Text for consent button'),
    '#default_value' => variable_get('klaro_consent_button_text', t('Manage cookie consent')),
  );

  // Get all implementations an build form.
  $implementations = klaro_get_implementations();
  $implementation_settings = variable_get('klaro_implementations', []);
  $form['klaro_implementations'] = array(
    '#type' => 'fieldset',
    '#title' => t('Enable klaro for the following scripts:'),
    '#tree' => TRUE,
  );
  foreach ($implementations as $implementation => $data) {
    if (isset($implementation_settings[$implementation])) {
      $default_value = $implementation_settings[$implementation]['enabled'];
      $default_required = $implementation_settings[$implementation]['required'];
      $default_title = $implementation_settings[$implementation]['title'];
      $default_description = $implementation_settings[$implementation]['description'];
      $default_info_link = $implementation_settings[$implementation]['info_link'];
      $default_privacy_link = $implementation_settings[$implementation]['privacy_link'];
      $default_cookies = $implementation_settings[$implementation]['advanced_settings']['cookies'];
    }
    else {
      // Per default new modules are enabled.
      $default_value = TRUE;
      $default_required = $data['klaro']['required'];
      $default_title = $data['title'];
      $default_description = $data['description'];
      $default_info_link = $data['info_link'];
      $default_privacy_link = $data['privacy_link'];
      $default_cookies = $data['klaro']['cookies'];
    }

    $form['klaro_implementations'][$implementation] = array(
      '#type' => 'fieldset',
      '#title' => $data['title'],
      '#description' => $data['description'],
      '#tree' => TRUE,
    );
    $form['klaro_implementations'][$implementation]['enabled'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enabled'),
      '#default_value' => $default_value,
    );
    $form['klaro_implementations'][$implementation]['title'] = array(
      '#type' => 'textfield',
      '#title' => t('Override Title'),
      '#description' => t('Default value: <em>@title</em>', array('@title' => $data['title'])),
      '#default_value' => $default_title,
    );
    $form['klaro_implementations'][$implementation]['description'] = array(
      '#type' => 'textfield',
      '#title' => t('Override Description'),
      '#description' => t('Default value: <em>@description</em>', array('@description' => $data['description'])),
      '#default_value' => $default_description,
    );
    $form['klaro_implementations'][$implementation]['info_link'] = array(
      '#type' => 'textfield',
      '#title' => t('Override Info-Link'),
      '#description' => t('Default value: <em>@info_link</em>', array('@info_link' => $data['info_link'])),
      '#default_value' => $default_info_link,
    );
    $form['klaro_implementations'][$implementation]['privacy_link'] = array(
      '#type' => 'textfield',
      '#title' => t('Override Privacy-Link'),
      '#description' => t('Default value: <em>@privacy_link</em>', array('@privacy_link' => $data['privacy_link'])),
      '#default_value' => $default_privacy_link,
    );
    $form['klaro_implementations'][$implementation]['required'] = array(
      '#type' => 'checkbox',
      '#title' => t('Required'),
      '#default_value' => $default_required,
    );
    $form['klaro_implementations'][$implementation]['advanced_settings'] = array(
      '#type' => 'fieldset',
      '#title' => t('Advanced settings'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['klaro_implementations'][$implementation]['advanced_settings']['cookies'] = array(
      '#type' => 'textarea',
      '#title' => t('Cookies'),
      '#description' => t('A string representing a JSON array of strings or regexes of the cookie name OR an array of arrays with 1. cookie name, 2. cookie path, 3. cookie domain.<br>Default value: <em>@cookies</em>', array('@cookies' => $data['klaro']['cookies'])),
      '#default_value' => $default_cookies,
    );
  }

  return system_settings_form($form);
}
